@@ -14,7 +14,7 @@ sa3 = Region("Statistical Area 3", "SA3", "SA3_NAME_2016")
 sa2 = Region("Statistical Area 2", "SA2", "SA2_NAME_2016")
 sa1 = Region("Statistical Area 1", "SA1", "SA1_7DIGITCODE_2016")
 
-mb = Region("Meshblock","MB","MB_CODE_2016")
+mb = Region("Meshblock", "MB", "MB_CODE_2016")
 
 AUS = GeoHierarchy(country, "Australia")
 
@@ -32,7 +32,8 @@ AUS.add_region(region=sa2, parent_region=sa3)
 AUS.add_region(region=sa1, parent_region=sa2)
 AUS.add_region(region=mb, parent_region=sa1)
 
-AUS.add_type(lga,"Administrative")
-AUS.add_type(sa4,"ASGS","Australian Statistical Geography Standard")
+AUS.add_type(lga, "Administrative")
+AUS.add_type(sa4, "ASGS", "Australian Statistical Geography Standard")
 
-AUS.coordinate_boundary = [-43.58301104,-9.23000371, 96.82159219, 167.99384663]
+AUS.coordinate_boundary = [-43.58301104, -9.23000371,
+                           96.82159219, 167.99384663]
