@@ -14,6 +14,7 @@ color_code = {
     "red": Fore.RED,
     "green": Style.BRIGHT + Fore.GREEN,
 }
+# ANSI terminal control sequence to erase the current line
 erase_line = "\x1b[2K"
 
 
@@ -21,11 +22,20 @@ def print_text(
     text, color="default", in_place=False, **kwargs
 ):  # type: (str, str, bool, any) -> None
     """
-    print text to console
-    :param text string: text to print
-    :param color string: can be one of "red" or "green", or "default"
-    :param in_place boolean: whether to erase previous line and print in place
-    :param kwargs: other keywords passed to built-in print
+    Print text to console
+    Parameters
+    ----------
+    text : string
+           text to print
+    color : string
+            it can be one of "red" or "green", or "default"
+    in_place : boolean
+               whether to erase previous line and print in place
+    **kwargs : dict, optional
+             : other keywords passed to built-in print
+    Returns
+    -------
+    None
     """
     if in_place:
         print("\r" + erase_line, end="")
@@ -34,10 +44,19 @@ def print_text(
 
 def create_url(url):
     """
-    produce a URL that is compatible with Github's REST API from the input url
+    Produce a URL that is compatible with Github's REST API from the input url
     This can handle blob or tree paths.
+    Parameters
+    ----------
+    url : string
+          url to the data directory in Github repository
+    Returns
+    -------
+    apiurl      : string
+                  Github API url
+    downloadurl : string
+                  Download directory
 
-    :param url string: Url to the data directory in Github repository
     """
     repo_only_url = re.compile(
         r"https:\/\/github\.com\/[a-z\d](?:[a-z\d]|-(?=[a-z\d])){0,38}\/[a-zA-Z0-9]+$"
@@ -47,8 +66,10 @@ def create_url(url):
     # Check if the given url is a url to a GitHub repo.
     # If it is, inform the user to use 'git clone' to download it
     if re.match(repo_only_url, url):
+
         print_text(
-            "✘ The given url is a complete repository. Use 'git clone' to download the repository",
+            "✘ The given url is a complete repository. "
+            "Use 'git clone' to download the repository",
             "red",
             in_place=True,
         )
@@ -69,8 +90,16 @@ def create_url(url):
 
 def download_data(country="Australia", output_dir=CWD):
     """
-    Downloads the files and directories and sub-directories in repo_url.
-    param country string: country name which will be sub-directory name example - data/Australia/
+    download the files and directories and sub-directories in repo_url.
+
+    Parameters
+    ----------
+    country : str
+              country name which will be sub-directory name example - data/Australia/
+    Return
+    ------
+    total_file  : int
+                  number of total files downloaded
     """
 
     # This is the temporary place to host of data files.
@@ -81,19 +110,19 @@ def download_data(country="Australia", output_dir=CWD):
         + "/"
     )
 
-    # generate the url which returns the JSON data
+    # Generate the url which returns the JSON data
     api_url, download_dirs = create_url(repo_url)
 
-    # To handle file names.
+    # Handle the directory path, Sync the path in Git and the path in local
     if len(download_dirs.split(".")) == 0:
         dir_out = os.path.join(output_dir, download_dirs)
     else:
-        print("length ", len(download_dirs.split(".")))
         dir_out = os.path.join(output_dir, "/".join(download_dirs.split("/")[:-1]))
 
-    # make a directory with the name which is taken from the actual repo
+    # Make a directory in the local with the name which is taken from the actual repo
     os.makedirs(dir_out, exist_ok=True)
 
+    # Open the URL
     try:
         opener = request.build_opener()
         opener.addheaders = [("User-agent", "Mozilla/5.0")]
@@ -101,21 +130,22 @@ def download_data(country="Australia", output_dir=CWD):
         response = request.urlretrieve(api_url)
     except KeyboardInterrupt:
         # when CTRL+C is pressed during the execution of this script,
-        # bring the cursor to the beginning, erase the current line, and dont make a new line
+        # bring the cursor to the beginning,
+        # erase the current line, and dont make a new line
         print_text("✘ Got interrupted", "red", in_place=True)
         sys.exit()
 
     # total files count
     total_files = 0
 
-    ## Writing into file
+    # Writing into file
     with open(response[0], "r") as f:
         data = json.load(f)
         # getting the total number of files so that we
         # can use it for the output information later
         total_files += len(data)
 
-        # If the data is a file, download it as one.
+        # If the data is a single file, download it as one.
         if isinstance(data, dict) and data["type"] == "file":
             try:
                 # download the file
@@ -125,9 +155,10 @@ def download_data(country="Australia", output_dir=CWD):
                 request.urlretrieve(
                     data["download_url"], os.path.join(dir_out, data["name"])
                 )
-                # bring the cursor to the beginning, erase the current line, and dont make a new line
+                # bring the cursor to the beginning,
+                # erase the current line, and dont make a new line
                 print_text(
-                    "Downloaded====: " + Fore.WHITE + "{}".format(data["name"]),
+                    "Downloaded: " + Fore.WHITE + "{}".format(data["name"]),
                     "green",
                     in_place=True,
                 )
@@ -135,17 +166,18 @@ def download_data(country="Australia", output_dir=CWD):
 
             except KeyboardInterrupt:
                 # when CTRL+C is pressed during the execution of this script,
-                # bring the cursor to the beginning, erase the current line, and dont make a new line
+                # bring the cursor to the beginning,
+                # erase the current line, and dont make a new line
                 print_text("✘ Got interrupted", "red", in_place=False)
                 sys.exit()
 
+        # If Data is a directory which contains a list of file, not a single file
         for file in data:
             file_url = file["download_url"]
             file_name = file["name"]
 
             path = file["path"]
             dirname = os.path.dirname(path)
-            print("path", path)
 
             if dirname != "":
                 os.makedirs(os.path.dirname(path), exist_ok=True)
@@ -160,7 +192,8 @@ def download_data(country="Australia", output_dir=CWD):
                     # download the file
                     request.urlretrieve(file_url, path)
 
-                    # bring the cursor to the beginning, erase the current line, and dont make a new line
+                    # bring the cursor to the beginning,
+                    # erase the current line, and dont make a new line
                     print_text(
                         "Downloaded" + Fore.WHITE + "{}".format(file_name),
                         "green",
@@ -170,8 +203,10 @@ def download_data(country="Australia", output_dir=CWD):
                     )
 
                 except KeyboardInterrupt:
-                    # when CTRL+C is pressed during the execution of this script,
-                    # bring the cursor to the beginning, erase the current line, and dont make a new line
+                    # when CTRL+C is pressed during
+                    # the execution of this script,
+                    # bring the cursor to the beginning,
+                    # erase the current line, and dont make a new line
                     print_text("✘ Got interrupted", "red", in_place=False)
                     sys.exit()
             else:
@@ -189,6 +224,7 @@ def download():
         # disbale CTRL+Z
         signal.signal(signal.SIGTSTP, signal.SIG_IGN)
 
+    # Parse the directory i.e country name
     parser = argparse.ArgumentParser(
         description="Download directories/folders from GitHub"
     )
@@ -196,8 +232,9 @@ def download():
     parser.add_argument(
         "--country",
         "-cty",
-        action="store_true",
-        help="The country of data to which the matching will apply to. (Default is Australia if not specified)",
+        type=str,
+        default="Australia",
+        help="Name of the country for which the reference data to download",
     )
 
     args = parser.parse_args()
